@@ -1,5 +1,6 @@
 #!/usr/bin/env python3
-# -*- coding: utf-8 -*-
+
+from __future__ import annotations
 
 import cProfile
 import os.path
@@ -7,7 +8,7 @@ import pstats
 import sys
 from pathlib import Path
 from time import perf_counter
-from typing import Any, List
+from typing import Any
 
 import click
 import rich.traceback
@@ -15,7 +16,7 @@ import typer
 import typer.core
 from typer import Option
 
-from . import __version__, cmdlist, resources
+from . import __version__, cmdlist, resources  # type: ignore
 from .utils import Verbosity
 from .utils.config import set_config
 
@@ -32,7 +33,7 @@ HELP = {
     "quiet": "Show only fatal error messages in program output.",
 }
 
-starttime = 0
+starttime = 0.0
 
 
 def print_version(value: bool) -> None:
@@ -64,7 +65,6 @@ def callback(
         help=print_version.__doc__,
     ),
 ) -> None:
-
     rich.traceback.install()
 
     global starttime
@@ -97,7 +97,6 @@ def callback(
 
 
 def result_callback(exit_code: int, **kwargs: Any) -> None:
-
     global profiler
     if profiler is not None:
         profiler.disable()
@@ -131,7 +130,7 @@ class RunCommand(typer.core.TyperCommand):
 
 @app.command(options_metavar="[options]", no_args_is_help=True, cls=RunCommand)
 def run(
-    cmdlists: List[Path] = typer.Argument(
+    cmdlists: list[Path] = typer.Argument(
         None,
         metavar="<cmdlist> ...",
         show_default=False,
