@@ -1,56 +1,52 @@
-# -*- coding: utf-8 -*-
+from __future__ import annotations
 
 import inspect
 import shlex
 from inspect import signature
 from pathlib import Path
-from typing import Callable, Dict
+from typing import Callable
 
 import click
 from typer import Context
 
-from . import core
+from . import core  # type: ignore
 from .utils.logging import error, format_filename, info
 
 __all__ = ["run", "format_options"]
 
-
-COMMANDS: Dict[str, Callable] = {
-    "load kle": core.KleFile.load,
+COMMANDS: dict[str, Callable] = {
+    "load kle": core.layout.load,
     "load font": core.font.load,
-    "load icons": core.icon.load,
+    # "load icons": core.icon.load, # TODO staticintlucas/keyset-rs#7
     "load profile": core.profile.load,
-    "generate layout": core.Layout.layout,
+    "generate layout": core.layout.layout,
     # "generate texture": # TODO generate a texture file (for renders, etc.)
     "save svg": core.save.as_svg,
     "save png": core.save.as_png,
     "save pdf": core.save.as_pdf,
     "save ai": core.save.as_ai,
-    "newfont": core.fontgen.fontgen,
 }
 
 
 def run(filepath: Path) -> None:
-
-    context = core.Context(filepath)
+    context = core.Context(str(filepath))
 
     try:
         with filepath.open() as file:
             for line in file:
                 run_line(context, line)
-    except IOError as e:
-        error(IOError(f"cannot open command list {format_filename(filepath)}: {e.strerror}"))
+    except OSError as e:
+        error(OSError(f"cannot open command list {format_filename(filepath)}: {e.strerror}"))
 
 
 def run_line(context: core.Context, string: str) -> None:
-
     line = shlex.split(string, comments=True)
 
     if len(line) == 0:
         return
 
-    for cmd, fn in COMMANDS.items():
-        cmd = cmd.split()
+    for c, fn in COMMANDS.items():
+        cmd = c.split()
         if len(line) >= len(cmd) and line[: len(cmd)] == cmd:
             command = cmd
             func = fn
@@ -58,7 +54,7 @@ def run_line(context: core.Context, string: str) -> None:
     else:
         raise ValueError(f"invalid command '{line[0]}'")
 
-    info(f"executing command '{command}'", file=context.name)
+    info(f"executing command '{' '.join(command)}'", file=context.name)
 
     num_args = len(signature(func).parameters) - 1  # Subtract one for the context
     args = line[len(command) :]
@@ -72,10 +68,8 @@ def run_line(context: core.Context, string: str) -> None:
 
 
 def format_options(ctx: Context, formatter: click.HelpFormatter) -> None:
-
     items = []
     for cmd, fun in COMMANDS.items():
-
         empty = inspect.Parameter.empty
         args = [
             f"<{p.name}>" if p.default is empty else f"[{p.name}]"
